@@ -1,6 +1,6 @@
+from system_cmd import system_run
+from .structures import ActionException
 import os
-from .utils import system_cmd_fail
-from patience.structures import ActionException
 
 def replace_variables(path, rules):
     for k, v in rules:
@@ -57,15 +57,23 @@ def get_friendly(path, use_environment=True):  # TODO: make switch
 
     return result
 
-class Resource: 
+class Resource(object): 
     def __init__(self, config):
         self.config = config
         self.destination = config['dir']
+        
+        if not os.path.isabs(self.destination):
+            msg = 'Expected all abspath %r' % config
+            raise Exception(msg)
         self.short_path = config.get('nick', get_friendly(self.destination))
         
         if os.path.exists(os.path.join(self.destination, 'setup.py')):
             self.config['install'] = 'setuptools'
 
+        if not os.path.exists(self.destination):
+            # print('Resource warning: %r does not exist %r' % (self.destination, self.config))
+            pass
+
     def is_downloaded(self):
         return os.path.exists(self.destination)
     
@@ -107,11 +115,11 @@ class Resource:
             self.run('python setup.py develop')
         elif install_type == 'cmake':
             # XXX: qui come va?
-            system_cmd_fail(self.destination, 'cmake -DCMAKE_INSTALL_PREFIX=${BVENV_PREFIX} .')
+            system_run(self.destination, 'cmake -DCMAKE_INSTALL_PREFIX=${BVENV_PREFIX} .')
         elif install_type == 'make':
             self.run('make')
             # XXX:
-            system_cmd_fail(self.destination, 'make install')
+            system_run(self.destination, 'make install')
         
         else:
             raise ActionException('Unknown install type %r.' % install_type)
